==> haskell-websockets-0.9.7.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.9.7.0
id: websockets-0.9.7.0-AMISw7YQfH3FgtGyHkdWpk
key: websockets-0.9.7.0-AMISw7YQfH3FgtGyHkdWpk
license: BSD3
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2013 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
abi: 9c9b68ffcb3c6dd8b165a21cce13967f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/websockets-0.9.7.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/websockets-0.9.7.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/websockets-0.9.7.0
hs-libraries: HSwebsockets-0.9.7.0-AMISw7YQfH3FgtGyHkdWpk
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    attoparsec-0.13.0.2-4oqBQA8Yjg9Kon1ukf0gbT base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz containers-0.5.7.1
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    random-1.1-54KmMHXjttlERYcr1mvsAe
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.9.7.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.9.7.0
id: websockets-0.9.7.0-AsDPiffwu1DGUTNZevxinw
key: websockets-0.9.7.0-AsDPiffwu1DGUTNZevxinw
license: BSD3
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2013 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
abi: 66f4ed97b45052f15fecb8de57a678c0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/websockets-0.9.7.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/websockets-0.9.7.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/websockets-0.9.7.0
hs-libraries: HSwebsockets-0.9.7.0-AsDPiffwu1DGUTNZevxinw
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz containers-0.5.7.1
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    random-1.1-54KmMHXjttlERYcr1mvsAe
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
